@@ -130,13 +130,12 @@ ORDER BY pedon_View_1.peiid ;"
 	multi.siteobs <- unique(sfr[, c("siteiid","siteobsiid")])
 	multisite <- table(multi.siteobs$siteiid) 
 	if (any(multisite > 1)) {
-	  message("-> QC: surface fragment records from multiple site observations.\n\tUse `get('multisiteobs.surface', envir=get_soilDB_env())` for site (siteiid) and site observation (siteobsiid)")
 	  assign("multisiteobs.surface", value = multi.siteobs[multi.siteobs$siteiid %in% names(multisite[multisite > 1]),], envir = get_soilDB_env())
 	}
 	
 	phs <- simplifyFragmentData(
 	  uncode(sfr, dsn = dsn),
-	  id.var = "peiid",
+	  id.var = "siteobsiid",
 	  vol.var = "sfragcov",
 	  prefix = "sfrag",
 	  msg = "surface fragment cover"
